@@ -355,7 +355,7 @@ class AlephAPI(object):
 
     def write_entity(
         self, collection_id: str, entity: Dict, entity_id: str = None, **kw
-    ) -> None:
+    ) -> Dict:
         """Create a single entity via the API, in the given
         collection.
 
@@ -368,7 +368,9 @@ class AlephAPI(object):
         entity: A dict object containing the values of the entity
         """
         entity["collection_id"] = collection_id
-        entity["id"] = entity_id
+
+        if entity_id is not None:
+            entity["id"] = entity_id
 
         for attempt in count(1):
             if entity_id is not None:
@@ -376,9 +378,7 @@ class AlephAPI(object):
             else:
                 url = self._make_url("entities")
             try:
-                response = self.session.post(url, json=entity)
-                response.raise_for_status()
-                return
+                return self._request("POST", url, data=entity)
             except RequestException as exc:
                 ae = AlephException(exc)
                 if not ae.transient or attempt > self.retries:
@@ -386,6 +386,8 @@ class AlephAPI(object):
                     raise exc
                 backoff(ae, attempt)
 
+        return {}
+
     def write_entities(
         self, collection_id: str, entities: Iterable, chunk_size: int = 1000, **kw
     ):
